{# Copyright (C) 2021 CERN. Copyright (C) 2021 Graz University of Technology. Invenio App RDM is free software; you can redistribute it and/or modify it under the terms of the MIT License; see LICENSE file for more details. #} {%- set title = _("Search guide") %} {%- extends "invenio_theme/page.html" %} {%- block page_body %}

# Suchanleitung

Diese Anleitung erklärt anhand von leicht verständlichen Beispielen, wie man erweiterte Suchanfragen schreibt.

### Einfache Suche (ein oder mehrere Begriffe)

Beispiel: `open science`

Die Ergebnisse entsprechen Datensätzen mit den Begriffen `open` oder `science` in einem beliebigen Feld. Beachten Sie, dass die Abstammung angewendet wird, so dass z. B. `science` auch mit `sciences`übereinstimmt. Die Suchergebnisse werden nach einem Algorithmus geordnet, der Ihre Suchbegriffe berücksichtigt.

Sie können das Vorhandensein beider Terme entweder mit dem `+` oder dem `AND` Operator erzwingen:

Beispiele: `+open +science` oder `open AND science`

Sie können das Nichtvorhandensein eines oder mehrerer Begriffe mit dem Operator `-` oder `NOT` erzwingen:

Beispiele: `-open +science` oder `NOT open AND science`

### Phrasensuche

Beispiel: `"open science"`

Die Ergebnisse entsprechen Datensätzen mit der phrase `open science` in einem beliebigen Feld.

### Feldsuche

Beispiel: `metadata.title:open`

Die Ergebnisse stimmen mit Datensätzen überein, bei denen der Begriff `open` im Feld `metadata.title`ist. Wenn Sie nach mehreren Begriffen im Titel suchen möchten, müssen Sie die Begriffe mit Klammern gruppieren:

Beispiel: `metadata.title:(open science)`

Die vollständige Liste der Felder, die Sie durchsuchen können, finden Sie in der Feldreferenz unten.

### Kombinierte einfache Phrasen- oder Feldsuche

Beispiel: `+metadata.title:"open science" -metadata.title:policy` oder z. B. `metadata.title:(-open +science)`

Sie können einfache Phrasen- und Feldsuche kombinieren, um erweiterte Suchanfragen zu konstruieren.

### Bereichssuche

Beispiel: `metadata.publication_date:[2017 TO 2018]` (Achtung, `TO` muss großgeschrieben werden).

Die Ergebnisse entsprechen allen Datensätzen mit einem Veröffentlichungsdatum zwischen 2017-01-01 und 2018-01-01 (beide Daten inklusive).

Beachten Sie, dass partielle Daten zu vollständigen Daten erweitert werden, z. B.:

- 2017 wird erweitert auf 2017-01-01
- 2017-06 wird erweitert auf 2017-06-01

Verwenden Sie eckige Klammern (`[]`) für einschließende Bereiche und geschweifte Klammern (`{}`) für ausschließende Bereiche, z. B.:

- `[2017 TO 2018}` ist aufgrund der Datumserweiterung und der exklusiven Obergrenze äquivalent zu `[2017-01-01 TO 2017-12-31]`.

Beispiele für andere Bereiche:

- `metadata.publication_date:{* TO 2017-01-01}`: Alle Tage bis 2017.
- `metadata.publication_date:[2017-01-01 TO *]`: Alle Tage von 2017.

### Ranking/Sortierung

Standardmäßig werden alle Suchen nach einem internen Ranking-Algorithmus sortiert, der jede Übereinstimmung mit Ihrer Abfrage bewertet. Sowohl in der Benutzeroberfläche als auch in der REST-API ist es möglich, die Ergebnisse zu sortieren nach:

- Aktuellste
- Beste Übereinstimmung

### Reguläre Ausdrücke

Reguläre Ausdrücke sind eine mächtige Sprache für den Mustervergleich, mit der man nach bestimmten Mustern in einem Feld suchen kann. Wenn Sie zum Beispiel alle Datensätze mit dem DOI-Präfix 10.5281 finden wollen, können Sie eine Suche mit regulären Ausdrücken verwenden:

Beispiel: `metadata.subjects.identifier:/03yrm5c2[1,6]/`

Vorsicht, der reguläre Ausdruck muss mit dem gesamten Feldwert übereinstimmen. Weitere Einzelheiten finden Sie in der Syntax des regulären Ausdrucks .

### Fehlende Werte

Es ist möglich, mit den Feldnamen `_exists_` und `_missing_` nach Datensätzen zu suchen, in denen entweder ein Wert fehlt oder die einen Wert in einem bestimmten Feld haben.

Beispiel: `_missing_:metadata.additional_titles` (alle Datensätze ohne metadata.additional_titles)

Beispiel: `_exists_:metadata.creators` (alle Datensätze mit metadata.creators)

### Erweiterte Konzepte

#### Boosten

Sie können den Boost-Operator `^` verwenden, wenn ein Begriff relevanter ist als ein anderer. Sie können z. B. nach allen Datensätzen suchen, die den Ausdruck open science entweder im title oder im description Feld enthalten, aber Datensätze mit dem Ausdruck im title Feld höher einstufen:

Beispiel: `metadata.title:"open science"^5 metadata.description:"open science"`

#### Unschärfe

Mit dem Fuzzy-Operator `~`können Sie nach Begriffen suchen, die Ihrem Suchbegriff ähnlich, aber nicht genau gleich sind.

Beispiel: `oepn~`

Die Ergebnisse entsprechen Datensätzen mit ähnlichen Begriffen (oder Rechtschreibfehlern) wie `oepn` die z. B. auch auf `open` passen würden.

#### Näherungssuche

Eine Phrasensuche wie `"open science"` (mit Anführungszeichen) erwartet standardmäßig alle Begriffe in genau der gleichen Reihenfolge und würde daher z. B. nicht auf einen Datensatz passen, der die Phrase "open access and science" enthält. Eine Proximity-Suche erlaubt, dass die Begriffe nicht in der exakten Reihenfolge stehen und auch andere Begriffe dazwischen enthalten können. Der Grad der Flexibilität wird anschließend durch eine Ganzzahl angegeben:

Beispiel: `"open science"~5`

#### Wildcards

Sie können Wildcards in Suchbegriffen verwenden, um ein einzelnes Zeichen (mit dem `?` Operator) oder keines bis mehrere Zeichen (mit dem `*` Operator) zu ersetzen.

Beispiel: `ope? scien*`

Platzhaltersuchen können langsam sein und sollten normalerweise nach Möglichkeit vermieden werden.

{%- endblock page_body%}